It is python package to connect to snowflake via snowflake-connector

Functions in package are:

class make_connection consist of function 1 and 2
1.connection_1(self,username,location,account_identifier,encryption_key,warehouse,database,schema):
    it makes the connection to snowflake via key pair(public private key generated by openssl)
    Parameters:
        1.username specifies the username for your account
        2.location specifies location of private key in your system
        3.account_identifier specifies the account_identifier of your account
        4.encryption_key specifies the password to decrypt private key
        5.warehouse specifies name of warehouse
        6.database specifies name of database
        7.schema specifies name of schema
2.connection_1(self,username,account_identifier,password,warehouse,database,schema):
    it makes the connection to snowflake via username and password
    Parameters:
        1.username specifies the username for your account
        2.account_identifier specifies the account_identifier of your account
        3.password specifies the password of your account
        4.warehouse specifies name of warehouse
        5.database specifies name of database
        6.schema specifies name of schema

Note: Key pair is more secure way to connect to snowflake

class run_query consist of function 3 and 4
3.run_select_query(self,con,sql_query):
    Here you pass query and it return pandas dataframe(used where output will be table rows)
    Parameters:
        1.con specifies connection object
        2.sql_query specifies sql_query in string

4.run_query(self,con,sql_query):
    Here you pass query and it return output of query(used where table rows are not returned)
    Parameters:
        1.con specifies connection object
        2.sql_query specifies sql_query in string


